==> qmmp-1.6.9.tar.bz2: qmmp-1.6.9/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="14"/>
        <source>Add Files</source>
        <translation>添加文件</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="177"/>
        <source>Up</source>
        <translation>向上</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="180"/>
        <location filename="../qmmpfiledialog.ui" line="193"/>
        <location filename="../qmmpfiledialog.ui" line="212"/>
        <location filename="../qmmpfiledialog.ui" line="237"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="190"/>
        <source>List view</source>
        <translation>列表视图</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="209"/>
        <source>Detailed view</source>
        <translation>详细视图</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="234"/>
        <source>Close dialog on add</source>
        <translation>关闭对话并打开已添加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="106"/>
        <source>File name:</source>
        <translation>文件名：</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="122"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="129"/>
        <source>Files of type:</source>
        <translation>文件类型：</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="155"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="70"/>
        <location filename="../qmmpfiledialog.cpp" line="80"/>
        <source>Qmmp File Dialog</source>
        <translation>Qmmp 文件对话</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="79"/>
        <source>About Qmmp File Dialog</source>
        <translation>关于 Qmmp 文件对话</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="81"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="84"/>
        <source>Some code is copied from the Qt library</source>
        <translation>一些源码基于 Qt 库</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="263"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="276"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="290"/>
        <source>Directories</source>
        <translation>目录</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="480"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 早已存在。
你想要替换它吗？</translation>
    </message>
</context>
</TS>

==> qmmp-1.7.9.tar.bz2: qmmp-1.7.9/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="14"/>
        <source>Add Files</source>
        <translation>添加文件</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="198"/>
        <source>Up</source>
        <translation>向上</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="201"/>
        <location filename="../qmmpfiledialog.ui" line="214"/>
        <location filename="../qmmpfiledialog.ui" line="233"/>
        <location filename="../qmmpfiledialog.ui" line="258"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="211"/>
        <source>List view</source>
        <translation>列表视图</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="230"/>
        <source>Detailed view</source>
        <translation>详细视图</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="255"/>
        <source>Close dialog on add</source>
        <translation>关闭对话并打开已添加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="124"/>
        <source>File name:</source>
        <translation>文件名：</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="140"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="147"/>
        <source>Files of type:</source>
        <translation>文件类型：</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="173"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="70"/>
        <location filename="../qmmpfiledialog.cpp" line="80"/>
        <source>Qmmp File Dialog</source>
        <translation>Qmmp 文件对话</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="79"/>
        <source>About Qmmp File Dialog</source>
        <translation>关于 Qmmp 文件对话</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="81"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>作者：
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="84"/>
        <source>Some code is copied from the Qt library</source>
        <translation>一些源码基于 Qt 库</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="251"/>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="264"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="278"/>
        <source>Directories</source>
        <translation>目录</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="465"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 早已存在。
你想要替换它吗？</translation>
    </message>
</context>
</TS>
